(* mclu: Mini Cloud
 * Copyright (C) 2014-2015 Red Hat Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *)

(** Simple forking parallel primitives. *)

val iter : ('a -> unit) -> 'a list -> unit
(** [iter f xs] iterates over each member [x] of the list [xs],
    running [f x] in parallel in a forked subprocess.  If [f] throws
    an exception then the function exits with an error. *)

val map : ('a -> 'b) -> 'a list -> bytes list
(** [map f xs] maps over each member [x] of the list [xs], running
    [f x] in parallel in a forked subprocess.

    The list of {b marsalled} values from [f] is returned - you have
    to unmarshall them (to get back the ['b]) using
    {!Marshal.from_bytes}.

    If [f] throws an exception, then the function exits with an
    error. *)
